@@ -66,6 +66,7 @@ usage (char * progname)
   printf ("Options:\n");
   printf ("  --vorbis                  Use Vorbis as the output codec\n");
   printf ("  --speex                   Use Speex as the output codec\n");
+  printf ("  --flac                    Use Flac as the output codec\n");
   printf ("  --interleave              Use interleaved PCM internally\n");
   exit (1);
 }
@@ -147,7 +148,7 @@ fs_encdec_new (char * infilename, char * outfilename, int format,
   oggz_set_read_callback (ed->oggz_in, -1, read_packet, ed);
   ed->serialno = oggz_serialno_new (ed->oggz_out);
 
-  ed->decoder = fish_sound_new (FISH_SOUND_DECODE, &fsinfo);
+  ed->decoder = fish_sound_new (FISH_SOUND_DECODE, NULL);
 
   fish_sound_set_interleave (ed->decoder, interleave);
 
@@ -156,7 +157,7 @@ fs_encdec_new (char * infilename, char * outfilename, int format,
   ed->format = format;
   ed->begun = 0;
   ed->b_o_s = 1;
-  ed->channels = fsinfo.channels;
+  ed->channels = fsinfo.channels; /* FIXME: fsinfo is unitialized! */
   ed->interleave = interleave;
 
   if (interleave) {
@@ -224,6 +225,8 @@ main (int argc, char ** argv)
       format = FISH_SOUND_VORBIS;
     } else if (!strcmp (argv[i], "--speex")) {
       format = FISH_SOUND_SPEEX;
+    } else if (!strcmp (argv[i], "--flac")) {
+      format = FISH_SOUND_FLAC;
     } else if (!strcmp (argv[i], "--interleave")) {
       interleave = 1;
     } else if (!strcmp (argv[i], "--help") || !strcmp (argv[i], "-h")) {
@@ -255,6 +258,15 @@ main (int argc, char ** argv)
     }
   }
 
+  if (format == FISH_SOUND_FLAC) {
+    if (HAVE_FLAC) {
+      printf ("Using Flac as the output codec\n");
+    } else {
+      fprintf (stderr, "Error: Flac support disabled\n");
+      exit (1);
+    }
+  }
+
   ed = fs_encdec_new (infilename, outfilename, format, interleave, blocksize);
 
   while ((n = oggz_read (ed->oggz_in, 1024)) > 0)
